@@ -54,6 +54,8 @@ static struct _PyGtk_FunctionStruct functions = {
 
     &PyGdkAtom_Type,  PyGdkAtom_New,
     pygdk_rectangle_from_pyobject,
+    pygtk_tree_path_to_pyobject,
+    pygtk_tree_path_from_pyobject,
 };
 
 static void
@@ -143,9 +145,6 @@ init_gtk(void)
     pygobject_register_sinkfunc(GTK_TYPE_INVISIBLE, sink_gtkinvisible);
     pygobject_register_sinkfunc(GTK_TYPE_OBJECT, sink_gtkobject);
 
-    /* set the default python encoding to utf-8 */
-    PyUnicode_SetDefaultEncoding("utf-8");
-
     /* initialise GTK ... */
     av = PySys_GetObject("argv");
     if (av != NULL) {
@@ -274,6 +273,8 @@ init_gtk(void)
 
     pygdk_register_classes(d);
     pygdk_add_constants(m, "GDK_");
+    PyModule_AddObject(m, "PARENT_RELATIVE",
+		       PyLong_FromLong(GDK_PARENT_RELATIVE));
       /* Add predefined atoms */
 #define add_atom(name) { aname = gdk_atom_name((GDK_##name)); \
 PyModule_AddObject(m, #name, PyString_FromString(aname)); \
