@@ -18,7 +18,7 @@ class GdkTest(unittest.TestCase):
         gtk.gdk.pixmap_create_from_data(None, '\x00', 1, 1, 1,
                                         black, black)
 
-    def testWindow(self):
+    def _testWindow(self):
         common = {'finalized': False}
         def on_finalize():
             common['finalized'] = True
@@ -34,3 +34,15 @@ class GdkTest(unittest.TestCase):
         while gc.collect():
             pass
         assert common['finalized']
+
+
+    def testDrawIndexedImage(self):
+        w = gtk.Window()
+        w.realize()
+        w.window.draw_indexed_image(gtk.gdk.GC(w.window),
+                                    0, 0,
+                                    1, 2,
+                                    gtk.gdk.RGB_DITHER_NONE,
+                                    '\x00\x01',
+                                    1,
+                                    [0xdeadbe, 0xbebabe])
